# LPU

![version](https://img.shields.io/pypi/v/lpu.svg)
![python](https://img.shields.io/pypi/pyversions/lpu.svg)
![license](https://img.shields.io/pypi/l/lpu.svg)

LPU is a collection of utility classes/functions for language processing

## Installation

### installing from PyPI release

```shell
$ pip install --user lpu
```

### installing from GitHub master

```shell
$ pip install --user https://github.com/akivajp/lpu/archive/master.zip
```
